# Copyright 2021 The Pigweed Authors
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.
"""Utilities for building tools that interact with pw_rpc."""

from pw_rpc.console_tools.console import (
    Context,
    CommandHelper,
    ClientInfo,
    flattened_rpc_completions,
    alias_deprecated_command,
)
from pw_rpc.console_tools.functions import help_as_repr
from pw_rpc.console_tools.watchdog import Watchdog
